@@ -10,130 +10,8 @@ from zc.buildout import UserError
 import zc.recipe.egg
 import setuptools
 
-script_template = {
-    'wsgi': '''
+from boilerplate import script_template, versions
 
-%(relative_paths_setup)s
-import sys
-sys.path[0:0] = [
-  %(path)s,
-  ]
-%(initialization)s
-import %(module_name)s
-
-application = %(module_name)s.%(attrs)s(%(arguments)s)
-''',
-    'fcgi': '''
-
-%(relative_paths_setup)s
-import sys
-sys.path[0:0] = [
-  %(path)s,
-  ]
-%(initialization)s
-import %(module_name)s
-
-%(module_name)s.%(attrs)s(%(arguments)s)
-'''
-}
-
-
-settings_template = '''
-import os
-
-ADMINS = (
-    # ('Your Name', 'your_email@domain.com'),
-)
-
-MANAGERS = ADMINS
-
-DATABASE_ENGINE = 'sqlite3'    # 'postgresql_psycopg2', 'postgresql', 'mysql', 'sqlite3' or 'oracle'.
-DATABASE_NAME = '%(project)s.db'
-DATABASE_USER = ''             # Not used with sqlite3.
-DATABASE_PASSWORD = ''         # Not used with sqlite3.
-DATABASE_HOST = ''             # Set to empty string for localhost. Not used with sqlite3.
-DATABASE_PORT = ''             # Set to empty string for default. Not used with sqlite3.
-
-TIME_ZONE = 'America/Chicago'
-
-LANGUAGE_CODE = 'en-us'
-
-# Absolute path to the directory that holds media.
-# Example: "/home/media/media.lawrence.com/"
-MEDIA_ROOT = %(media_root)s
-
-# URL that handles the media served from MEDIA_ROOT. Make sure to use a
-# trailing slash if there is a path component (optional in other cases).
-# Examples: "http://media.lawrence.com", "http://example.com/media/"
-MEDIA_URL = '/media/'
-
-# URL prefix for admin media -- CSS, JavaScript and images. Make sure to use a
-# trailing slash.
-# Examples: "http://foo.com/media/", "/media/".
-ADMIN_MEDIA_PREFIX = '/admin_media/'
-
-# Don't share this with anybody.
-SECRET_KEY = '%(secret)s'
-
-MIDDLEWARE_CLASSES = (
-    'django.middleware.common.CommonMiddleware',
-    'django.contrib.sessions.middleware.SessionMiddleware',
-    'django.contrib.auth.middleware.AuthenticationMiddleware',
-    'django.middleware.doc.XViewMiddleware',
-)
-
-ROOT_URLCONF = '%(urlconf)s'
-
-
-INSTALLED_APPS = (
-    'django.contrib.auth',
-    'django.contrib.contenttypes',
-    'django.contrib.sessions',
-    'django.contrib.admin',
-)
-
-TEMPLATE_LOADERS = (
-    'django.template.loaders.filesystem.load_template_source',
-    'django.template.loaders.app_directories.load_template_source',
-)
-
-TEMPLATE_DIRS = (
-    os.path.join(os.path.dirname(__file__), "templates"),
-)
-
-
-'''
-
-production_settings = '''
-from %(project)s.settings import *
-'''
-
-development_settings = '''
-from %(project)s.settings import *
-DEBUG=True
-TEMPLATE_DEBUG=DEBUG
-'''
-
-urls_template = '''
-from django.conf.urls.defaults import patterns, include, handler500
-from django.conf import settings
-from django.contrib import admin
-admin.autodiscover()
-
-handler500 # Pyflakes
-
-urlpatterns = patterns(
-    '',
-    (r'^admin/', include(admin.site.urls)),
-    (r'^accounts/login/$', 'django.contrib.auth.views.login'),
-)
-
-if settings.DEBUG:
-    urlpatterns += patterns('',
-        (r'^media/(?P<path>.*)$', 'django.views.static.serve',
-         {'document_root': settings.MEDIA_ROOT}),
-    )
-'''
 
 class Recipe(object):
     def __init__(self, buildout, name, options):
@@ -176,7 +54,6 @@ class Recipe(object):
         self.install_from_cache = self.buildout['buildout'].get(
             'install-from-cache', '').strip() == 'true'
 
-
     def install(self):
         location = self.options['location']
         base_dir = self.buildout['buildout']['directory']
@@ -259,7 +136,6 @@ class Recipe(object):
 
         shutil.copytree(download_location, location)
 
-
     def install_release(self, version, download_dir, tarball, destination):
         extraction_dir = os.path.join(download_dir, 'django-archive')
         setuptools.archive_util.unpack_archive(tarball, extraction_dir)
@@ -292,11 +168,9 @@ class Recipe(object):
             [(self.options.get('control-script', self.name),
               'djangorecipe.manage', 'main')],
             ws, self.options['executable'], self.options['bin-directory'],
-            extra_paths = extra_paths,
-            arguments= "'%s.%s'" % (project,
-                                    self.options['settings']))
-
-
+            extra_paths=extra_paths,
+            arguments="'%s.%s'" % (project,
+                                   self.options['settings']))
 
     def create_test_runner(self, extra_paths, working_set):
         apps = self.options.get('test', '').split()
@@ -307,36 +181,44 @@ class Recipe(object):
                   'djangorecipe.test', 'main')],
                 working_set, self.options['executable'],
                 self.options['bin-directory'],
-                extra_paths = extra_paths,
-                arguments= "'%s.%s', %s" % (
+                extra_paths=extra_paths,
+                arguments="'%s.%s', %s" % (
                     self.options['project'],
                     self.options['settings'],
                     ', '.join(["'%s'" % app for app in apps])))
         else:
             return []
 
-
     def create_project(self, project_dir):
         os.makedirs(project_dir)
+        version = self.options['version']
+
+        # Check the version to deploy the corresponding boilerplate
+        # settings/urlsconf.
+        version_re = re.compile("\d+\.\d+")
+        match = version_re.match(version)
+        if match:
+            version = version_re.match(version).group()
+        config = versions.get(version, versions['trunk'])
 
         template_vars = {'secret': self.generate_secret()}
         template_vars.update(self.options)
 
         self.create_file(
             os.path.join(project_dir, 'development.py'),
-            development_settings, template_vars)
+            config['development_settings'], template_vars)
 
         self.create_file(
             os.path.join(project_dir, 'production.py'),
-            production_settings, template_vars)
+            config['production_settings'], template_vars)
 
         self.create_file(
             os.path.join(project_dir, 'urls.py'),
-            urls_template, template_vars)
+            config['urls'], template_vars)
 
         self.create_file(
             os.path.join(project_dir, 'settings.py'),
-            settings_template, template_vars)
+            config['settings'], template_vars)
 
         # Create the media and templates directories for our
         # project
@@ -368,7 +250,7 @@ class Recipe(object):
                         self.options['executable'],
                         self.options['bin-directory'],
                         extra_paths=extra_paths,
-                        arguments= "'%s.%s', logfile='%s'" % (
+                        arguments="'%s.%s', logfile='%s'" % (
                             project, self.options['settings'],
                             self.options.get('logfile'))))
         zc.buildout.easy_install.script_template = _script_template
@@ -406,7 +288,7 @@ class Recipe(object):
 
     def get_extra_paths(self):
         extra_paths = [self.options['location'],
-                       self.buildout['buildout']['directory']
+                       self.buildout['buildout']['directory'],
                        ]
 
         # Add libraries found by a site .pth files to our extra-paths.
